@@ -47,21 +47,20 @@
 ggcuminc <- function(x, outcome = NULL,
                      linetype_aes = FALSE,
                      theme = theme_ggsurvfit_default(), ...) {
-  # check inputs ---------------------------------------------------------------
-  if (!inherits(x, c("tidycuminc", "survfitms"))) {
-    cli_abort(
-      c("!" = "Argument {.code x} must be {.cls tidycuminc}.",
-        "i" = "Create the object with {.code tidycmprsk::cuminc()}.")
-    )
-  }
+# Combined check:
+if (!inherits(x, c("tidycuminc", "survfitms")) || inherits(x, "survfitcoxms")) {
+  cli_abort(
+    c("!" = "Object passed in argument {.arg x} must be class {.cls tidycuminc} or {.cls survfitms}. The {.cls survfitcoxms} class is not supported.",
+      "i" = "Create the cumulative incidence object using {.fun tidycmprsk::cuminc}.")
+  )
+}
 
   # prep data to be passed to ggplot() -----------------------------------------
-  if (inherits(x, "tidycuminc"))
+  if (inherits(x, "tidycuminc")) {
     df <- tidy_cuminc(x = x)
-  else if (inherits(x, "survfitms"))
+  } else if (inherits(x, "survfitms")) {
     df <- tidy_survfit(x = x)
-  # adding the model object to df
-  df <- df %>% dplyr::mutate(survfit = c(list(x), rep_len(list(), dplyr::n() - 1L)))
+  }
 
   # subset on outcome of interest ----------------------------------------------
   if (is.null(outcome)) {
@@ -73,6 +72,9 @@ ggcuminc <- function(x, outcome = NULL,
   }
   df <- dplyr::filter(df, .data$outcome %in% .env$outcome)
 
+  # adding the model object to df
+  df <- df %>% dplyr::mutate(survfit = c(list(x), rep_len(list(), dplyr::n() - 1L)))
+
   # construct aes() call -------------------------------------------------------
   aes_args <- .construct_aes(df, linetype_aes = linetype_aes, outcome = outcome)
 
