@@ -10,7 +10,14 @@ survival::Surv
 #' @export
 dplyr::`%>%`
 
+#' @importFrom grid grid.draw
+#' @export
+grid::grid.draw
+
 #' @importFrom ggplot2 %+%
 #' @export
 ggplot2::`%+%`
 
+#' @importFrom ggplot2 ggplot_add
+#' @export
+ggplot2::ggplot_add
